@@ -56,7 +56,7 @@ def gattr(obj, attr, default=None):
         return default
 
 
-class SSLWrapper:
+class SSLWrapper(object):
     """
     Abstract SSLWrapper base class
     """
@@ -120,7 +120,8 @@ class SSLWrapper:
                 if self.exc_str:
                     if self.strerror:
                         s += "(%s)" % self.exc_str
-                    else: s += "(%s)" % str(self.exc_args)
+                    else:
+                        s += "(%s)" % str(self.exc_args)
             return s
 
     def __init__(self, sslobj, sock=None):
@@ -157,7 +158,7 @@ class PyOpenSSLWrapper(SSLWrapper):
         self.parent.__init__(self, *args)
 
     def is_numtoolarge(self, e):
-        ''' Magic methods don't need documentation '''
+        """ Magic methods don't need documentation """
         t = ('asn1 encoding routines', 'a2d_ASN1_OBJECT', 'first num too large')
         return (isinstance(e.args, (list, tuple)) and len(e.args) == 1 and
                 isinstance(e.args[0], (list, tuple)) and len(e.args[0]) == 2 and
